@@ -206,6 +206,9 @@ def delete_circle_on_last_member_delete(sender, instance, **kwargs):
     # if this was the last member of the circle, the circle should be deleted too
     if instance.circle.pk is not None and instance.circle.members.count() == 0:
         instance.circle.delete()
+    
+    # delete any CircleAccessRequests which were made on this circle by this user
+    CircleAccessRequest.objects.filter(circle=instance.circle, user=instance.user).delete()
 
 @receiver(pre_delete, sender=CircleMember)
 def manage_deleted_owner(sender, instance, **kwargs):
