@@ -9,7 +9,7 @@ from djangoldp.tests.server_settings import yaml_config
 # override config loading
 config = {
     # add the packages to the reference list
-    'ldppackages': ['djangoldp_account', 'djangoldp_circle', 'djangoldp_circle.tests'],
+    'ldppackages': ['djangoldp_account', 'djangoldp_circle', 'djangoldp_circle.tests', 'djangoldp_notification'],
 
     # required values for server
     'server': {
@@ -43,6 +43,7 @@ failures = test_runner.run_tests([
     'djangoldp_circle.tests.tests_view',
     'djangoldp_circle.tests.tests_post',
     'djangoldp_circle.tests.tests_cache',
+    'djangoldp_circle.tests.tests_notifications',
 ])
 if failures:
     sys.exit(failures)
